@@ -135,11 +135,6 @@ impl<T> OpenCVType<'_> for Mat_<T> {
 	type ExternReceive = *mut c_void;
 	type ExternContainer = Self;
 
-	#[inline]
-	fn opencv_into_extern_container(self) -> Result<Self::ExternContainer> {
-		Ok(self)
-	}
-
 	#[inline]
 	fn opencv_into_extern_container_nofail(self) -> Self::ExternContainer {
 		self
@@ -154,11 +149,6 @@ impl<T> OpenCVType<'_> for Mat_<T> {
 impl<T> OpenCVTypeArg<'_> for Mat_<T> {
 	type ExternContainer = Self;
 
-	#[inline]
-	fn opencv_into_extern_container(self) -> Result<Self::ExternContainer> {
-		Ok(self)
-	}
-
 	#[inline]
 	fn opencv_into_extern_container_nofail(self) -> Self::ExternContainer {
 		self
