@@ -39,7 +39,9 @@ opencv_type_enum! { crate::bgsegm::LSBPCameraMotionCompensation }
 /// * is_parallel: true
 #[inline]
 pub fn create_background_subtractor_cnt(min_pixel_stability: i32, use_history: bool, max_pixel_stability: i32, is_parallel: bool) -> Result<core::Ptr<dyn crate::bgsegm::BackgroundSubtractorCNT>> {
-	unsafe { sys::cv_bgsegm_createBackgroundSubtractorCNT_int_bool_int_bool(min_pixel_stability, use_history, max_pixel_stability, is_parallel) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorCNT>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createBackgroundSubtractorCNT_int_bool_int_bool(min_pixel_stability, use_history, max_pixel_stability, is_parallel) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorCNT>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a GMG Background Subtractor
@@ -53,7 +55,9 @@ pub fn create_background_subtractor_cnt(min_pixel_stability: i32, use_history: b
 /// * decision_threshold: 0.8
 #[inline]
 pub fn create_background_subtractor_gmg(initialization_frames: i32, decision_threshold: f64) -> Result<core::Ptr<dyn crate::bgsegm::BackgroundSubtractorGMG>> {
-	unsafe { sys::cv_bgsegm_createBackgroundSubtractorGMG_int_double(initialization_frames, decision_threshold) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorGMG>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createBackgroundSubtractorGMG_int_double(initialization_frames, decision_threshold) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorGMG>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates an instance of BackgroundSubtractorGSOC algorithm.
@@ -87,7 +91,9 @@ pub fn create_background_subtractor_gmg(initialization_frames: i32, decision_thr
 /// * noise_removal_threshold_fac_fg: 0.0008f
 #[inline]
 pub fn create_background_subtractor_gsoc(mc: i32, n_samples: i32, replace_rate: f32, propagation_rate: f32, hits_threshold: i32, alpha: f32, beta: f32, blinking_supression_decay: f32, blinking_supression_multiplier: f32, noise_removal_threshold_fac_bg: f32, noise_removal_threshold_fac_fg: f32) -> Result<core::Ptr<dyn crate::bgsegm::BackgroundSubtractorGSOC>> {
-	unsafe { sys::cv_bgsegm_createBackgroundSubtractorGSOC_int_int_float_float_int_float_float_float_float_float_float(mc, n_samples, replace_rate, propagation_rate, hits_threshold, alpha, beta, blinking_supression_decay, blinking_supression_multiplier, noise_removal_threshold_fac_bg, noise_removal_threshold_fac_fg) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorGSOC>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createBackgroundSubtractorGSOC_int_int_float_float_int_float_float_float_float_float_float(mc, n_samples, replace_rate, propagation_rate, hits_threshold, alpha, beta, blinking_supression_decay, blinking_supression_multiplier, noise_removal_threshold_fac_bg, noise_removal_threshold_fac_fg) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorGSOC>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates an instance of BackgroundSubtractorLSBP algorithm.
@@ -125,7 +131,9 @@ pub fn create_background_subtractor_gsoc(mc: i32, n_samples: i32, replace_rate:
 /// * min_count: 2
 #[inline]
 pub fn create_background_subtractor_lsbp(mc: i32, n_samples: i32, lsbp_radius: i32, tlower: f32, tupper: f32, tinc: f32, tdec: f32, rscale: f32, rincdec: f32, noise_removal_threshold_fac_bg: f32, noise_removal_threshold_fac_fg: f32, lsb_pthreshold: i32, min_count: i32) -> Result<core::Ptr<dyn crate::bgsegm::BackgroundSubtractorLSBP>> {
-	unsafe { sys::cv_bgsegm_createBackgroundSubtractorLSBP_int_int_int_float_float_float_float_float_float_float_float_int_int(mc, n_samples, lsbp_radius, tlower, tupper, tinc, tdec, rscale, rincdec, noise_removal_threshold_fac_bg, noise_removal_threshold_fac_fg, lsb_pthreshold, min_count) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorLSBP>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createBackgroundSubtractorLSBP_int_int_int_float_float_float_float_float_float_float_float_int_int(mc, n_samples, lsbp_radius, tlower, tupper, tinc, tdec, rscale, rincdec, noise_removal_threshold_fac_bg, noise_removal_threshold_fac_fg, lsb_pthreshold, min_count) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorLSBP>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates mixture-of-gaussian background subtractor
@@ -144,7 +152,9 @@ pub fn create_background_subtractor_lsbp(mc: i32, n_samples: i32, lsbp_radius: i
 /// * noise_sigma: 0
 #[inline]
 pub fn create_background_subtractor_mog(history: i32, nmixtures: i32, background_ratio: f64, noise_sigma: f64) -> Result<core::Ptr<dyn crate::bgsegm::BackgroundSubtractorMOG>> {
-	unsafe { sys::cv_bgsegm_createBackgroundSubtractorMOG_int_int_double_double(history, nmixtures, background_ratio, noise_sigma) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorMOG>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createBackgroundSubtractorMOG_int_int_double_double(history, nmixtures, background_ratio, noise_sigma) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::bgsegm::BackgroundSubtractorMOG>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates an instance of SyntheticSequenceGenerator.
@@ -166,7 +176,9 @@ pub fn create_background_subtractor_mog(history: i32, nmixtures: i32, background
 pub fn create_synthetic_sequence_generator(background: &dyn core::ToInputArray, object: &dyn core::ToInputArray, amplitude: f64, wavelength: f64, wavespeed: f64, objspeed: f64) -> Result<core::Ptr<crate::bgsegm::SyntheticSequenceGenerator>> {
 	input_array_arg!(background);
 	input_array_arg!(object);
-	unsafe { sys::cv_bgsegm_createSyntheticSequenceGenerator_const__InputArrayR_const__InputArrayR_double_double_double_double(background.as_raw__InputArray(), object.as_raw__InputArray(), amplitude, wavelength, wavespeed, objspeed) }.into_result().map(|r| unsafe { core::Ptr::<crate::bgsegm::SyntheticSequenceGenerator>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_bgsegm_createSyntheticSequenceGenerator_const__InputArrayR_const__InputArrayR_double_double_double_double(background.as_raw__InputArray(), object.as_raw__InputArray(), amplitude, wavelength, wavespeed, objspeed) }.into_result()?;
+	let ret = unsafe { core::Ptr::<crate::bgsegm::SyntheticSequenceGenerator>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Background subtraction based on counting.
@@ -181,31 +193,36 @@ pub trait BackgroundSubtractorCNTConst: crate::video::BackgroundSubtractorConst
 	#[inline]
 	fn get_background_image(&self, background_image: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(background_image);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorCNT(), background_image.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorCNT(), background_image.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns number of frames with same pixel color to consider stable.
 	#[inline]
 	fn get_min_pixel_stability(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getMinPixelStability_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getMinPixelStability_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns maximum allowed credit for a pixel in history.
 	#[inline]
 	fn get_max_pixel_stability(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getMaxPixelStability_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getMaxPixelStability_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns if we're giving a pixel credit for being stable for a long time.
 	#[inline]
 	fn get_use_history(&self) -> Result<bool> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getUseHistory_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getUseHistory_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns if we're parallelizing the algorithm.
 	#[inline]
 	fn get_is_parallel(&self) -> Result<bool> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getIsParallel_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_getIsParallel_const(self.as_raw_BackgroundSubtractorCNT()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -219,31 +236,36 @@ pub trait BackgroundSubtractorCNT: crate::bgsegm::BackgroundSubtractorCNTConst +
 	fn apply(&mut self, image: &dyn core::ToInputArray, fgmask: &mut dyn core::ToOutputArray, learning_rate: f64) -> Result<()> {
 		input_array_arg!(image);
 		output_array_arg!(fgmask);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorCNT(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorCNT(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the number of frames with same pixel color to consider stable.
 	#[inline]
 	fn set_min_pixel_stability(&mut self, value: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setMinPixelStability_int(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setMinPixelStability_int(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the maximum allowed credit for a pixel in history.
 	#[inline]
 	fn set_max_pixel_stability(&mut self, value: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setMaxPixelStability_int(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setMaxPixelStability_int(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets if we're giving a pixel credit for being stable for a long time.
 	#[inline]
 	fn set_use_history(&mut self, value: bool) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setUseHistory_bool(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setUseHistory_bool(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets if we're parallelizing the algorithm.
 	#[inline]
 	fn set_is_parallel(&mut self, value: bool) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setIsParallel_bool(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorCNT_setIsParallel_bool(self.as_raw_mut_BackgroundSubtractorCNT(), value) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -261,7 +283,8 @@ pub trait BackgroundSubtractorGMGConst: crate::video::BackgroundSubtractorConst
 	/// Returns total number of distinct colors to maintain in histogram.
 	#[inline]
 	fn get_max_features(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMaxFeatures_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMaxFeatures_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the learning rate of the algorithm.
@@ -270,13 +293,15 @@ pub trait BackgroundSubtractorGMGConst: crate::video::BackgroundSubtractorConst
 	/// histograms.
 	#[inline]
 	fn get_default_learning_rate(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getDefaultLearningRate_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getDefaultLearningRate_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the number of frames used to initialize background model.
 	#[inline]
 	fn get_num_frames(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getNumFrames_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getNumFrames_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the parameter used for quantization of color-space.
@@ -284,19 +309,22 @@ pub trait BackgroundSubtractorGMGConst: crate::video::BackgroundSubtractorConst
 	/// It is the number of discrete levels in each channel to be used in histograms.
 	#[inline]
 	fn get_quantization_levels(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getQuantizationLevels_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getQuantizationLevels_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the prior probability that each individual pixel is a background pixel.
 	#[inline]
 	fn get_background_prior(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getBackgroundPrior_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getBackgroundPrior_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the kernel radius used for morphological operations
 	#[inline]
 	fn get_smoothing_radius(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getSmoothingRadius_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getSmoothingRadius_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the value of decision threshold.
@@ -304,25 +332,29 @@ pub trait BackgroundSubtractorGMGConst: crate::video::BackgroundSubtractorConst
 	/// Decision value is the value above which pixel is determined to be FG.
 	#[inline]
 	fn get_decision_threshold(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getDecisionThreshold_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getDecisionThreshold_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the status of background model update
 	#[inline]
 	fn get_update_background_model(&self) -> Result<bool> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getUpdateBackgroundModel_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getUpdateBackgroundModel_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the minimum value taken on by pixels in image sequence. Usually 0.
 	#[inline]
 	fn get_min_val(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMinVal_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMinVal_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Returns the maximum value taken on by pixels in image sequence. e.g. 1.0 or 255.
 	#[inline]
 	fn get_max_val(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMaxVal_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_getMaxVal_const(self.as_raw_BackgroundSubtractorGMG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -333,61 +365,71 @@ pub trait BackgroundSubtractorGMG: crate::bgsegm::BackgroundSubtractorGMGConst +
 	/// Sets total number of distinct colors to maintain in histogram.
 	#[inline]
 	fn set_max_features(&mut self, max_features: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMaxFeatures_int(self.as_raw_mut_BackgroundSubtractorGMG(), max_features) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMaxFeatures_int(self.as_raw_mut_BackgroundSubtractorGMG(), max_features) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the learning rate of the algorithm.
 	#[inline]
 	fn set_default_learning_rate(&mut self, lr: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setDefaultLearningRate_double(self.as_raw_mut_BackgroundSubtractorGMG(), lr) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setDefaultLearningRate_double(self.as_raw_mut_BackgroundSubtractorGMG(), lr) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the number of frames used to initialize background model.
 	#[inline]
 	fn set_num_frames(&mut self, nframes: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setNumFrames_int(self.as_raw_mut_BackgroundSubtractorGMG(), nframes) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setNumFrames_int(self.as_raw_mut_BackgroundSubtractorGMG(), nframes) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the parameter used for quantization of color-space
 	#[inline]
 	fn set_quantization_levels(&mut self, nlevels: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setQuantizationLevels_int(self.as_raw_mut_BackgroundSubtractorGMG(), nlevels) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setQuantizationLevels_int(self.as_raw_mut_BackgroundSubtractorGMG(), nlevels) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the prior probability that each individual pixel is a background pixel.
 	#[inline]
 	fn set_background_prior(&mut self, bgprior: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setBackgroundPrior_double(self.as_raw_mut_BackgroundSubtractorGMG(), bgprior) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setBackgroundPrior_double(self.as_raw_mut_BackgroundSubtractorGMG(), bgprior) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the kernel radius used for morphological operations
 	#[inline]
 	fn set_smoothing_radius(&mut self, radius: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setSmoothingRadius_int(self.as_raw_mut_BackgroundSubtractorGMG(), radius) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setSmoothingRadius_int(self.as_raw_mut_BackgroundSubtractorGMG(), radius) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the value of decision threshold.
 	#[inline]
 	fn set_decision_threshold(&mut self, thresh: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setDecisionThreshold_double(self.as_raw_mut_BackgroundSubtractorGMG(), thresh) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setDecisionThreshold_double(self.as_raw_mut_BackgroundSubtractorGMG(), thresh) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the status of background model update
 	#[inline]
 	fn set_update_background_model(&mut self, update: bool) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setUpdateBackgroundModel_bool(self.as_raw_mut_BackgroundSubtractorGMG(), update) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setUpdateBackgroundModel_bool(self.as_raw_mut_BackgroundSubtractorGMG(), update) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the minimum value taken on by pixels in image sequence.
 	#[inline]
 	fn set_min_val(&mut self, val: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMinVal_double(self.as_raw_mut_BackgroundSubtractorGMG(), val) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMinVal_double(self.as_raw_mut_BackgroundSubtractorGMG(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Sets the maximum value taken on by pixels in image sequence.
 	#[inline]
 	fn set_max_val(&mut self, val: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMaxVal_double(self.as_raw_mut_BackgroundSubtractorGMG(), val) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGMG_setMaxVal_double(self.as_raw_mut_BackgroundSubtractorGMG(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -401,7 +443,8 @@ pub trait BackgroundSubtractorGSOCConst: crate::video::BackgroundSubtractorConst
 	#[inline]
 	fn get_background_image(&self, background_image: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(background_image);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGSOC_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorGSOC(), background_image.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGSOC_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorGSOC(), background_image.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -415,7 +458,8 @@ pub trait BackgroundSubtractorGSOC: crate::bgsegm::BackgroundSubtractorGSOCConst
 	fn apply(&mut self, image: &dyn core::ToInputArray, fgmask: &mut dyn core::ToOutputArray, learning_rate: f64) -> Result<()> {
 		input_array_arg!(image);
 		output_array_arg!(fgmask);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorGSOC_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorGSOC(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorGSOC_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorGSOC(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -427,7 +471,8 @@ pub trait BackgroundSubtractorLSBPConst: crate::video::BackgroundSubtractorConst
 	#[inline]
 	fn get_background_image(&self, background_image: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(background_image);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBP_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorLSBP(), background_image.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBP_getBackgroundImage_const_const__OutputArrayR(self.as_raw_BackgroundSubtractorLSBP(), background_image.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -441,7 +486,8 @@ pub trait BackgroundSubtractorLSBP: crate::bgsegm::BackgroundSubtractorLSBPConst
 	fn apply(&mut self, image: &dyn core::ToInputArray, fgmask: &mut dyn core::ToOutputArray, learning_rate: f64) -> Result<()> {
 		input_array_arg!(image);
 		output_array_arg!(fgmask);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBP_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorLSBP(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBP_apply_const__InputArrayR_const__OutputArrayR_double(self.as_raw_mut_BackgroundSubtractorLSBP(), image.as_raw__InputArray(), fgmask.as_raw__OutputArray(), learning_rate) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -485,19 +531,22 @@ impl BackgroundSubtractorLSBPDesc {
 	#[inline]
 	pub fn calc_local_svd_values(local_svd_values: &mut dyn core::ToOutputArray, frame: &core::Mat) -> Result<()> {
 		output_array_arg!(local_svd_values);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_calcLocalSVDValues_const__OutputArrayR_const_MatR(local_svd_values.as_raw__OutputArray(), frame.as_raw_Mat()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_calcLocalSVDValues_const__OutputArrayR_const_MatR(local_svd_values.as_raw__OutputArray(), frame.as_raw_Mat()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn compute_from_local_svd_values(desc: &mut dyn core::ToOutputArray, local_svd_values: &core::Mat, lsbp_sample_points: &core::Point2i) -> Result<()> {
 		output_array_arg!(desc);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_computeFromLocalSVDValues_const__OutputArrayR_const_MatR_const_Point2iX(desc.as_raw__OutputArray(), local_svd_values.as_raw_Mat(), lsbp_sample_points) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_computeFromLocalSVDValues_const__OutputArrayR_const_MatR_const_Point2iX(desc.as_raw__OutputArray(), local_svd_values.as_raw_Mat(), lsbp_sample_points) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn compute(desc: &mut dyn core::ToOutputArray, frame: &core::Mat, lsbp_sample_points: &core::Point2i) -> Result<()> {
 		output_array_arg!(desc);
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_compute_const__OutputArrayR_const_MatR_const_Point2iX(desc.as_raw__OutputArray(), frame.as_raw_Mat(), lsbp_sample_points) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorLSBPDesc_compute_const__OutputArrayR_const_MatR_const_Point2iX(desc.as_raw__OutputArray(), frame.as_raw_Mat(), lsbp_sample_points) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -510,22 +559,26 @@ pub trait BackgroundSubtractorMOGConst: crate::video::BackgroundSubtractorConst
 
 	#[inline]
 	fn get_history(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getHistory_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getHistory_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_n_mixtures(&self) -> Result<i32> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getNMixtures_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getNMixtures_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_background_ratio(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getBackgroundRatio_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getBackgroundRatio_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_noise_sigma(&self) -> Result<f64> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getNoiseSigma_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_getNoiseSigma_const(self.as_raw_BackgroundSubtractorMOG()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -535,22 +588,26 @@ pub trait BackgroundSubtractorMOG: crate::bgsegm::BackgroundSubtractorMOGConst +
 
 	#[inline]
 	fn set_history(&mut self, nframes: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setHistory_int(self.as_raw_mut_BackgroundSubtractorMOG(), nframes) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setHistory_int(self.as_raw_mut_BackgroundSubtractorMOG(), nframes) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_n_mixtures(&mut self, nmix: i32) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setNMixtures_int(self.as_raw_mut_BackgroundSubtractorMOG(), nmix) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setNMixtures_int(self.as_raw_mut_BackgroundSubtractorMOG(), nmix) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_background_ratio(&mut self, background_ratio: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setBackgroundRatio_double(self.as_raw_mut_BackgroundSubtractorMOG(), background_ratio) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setBackgroundRatio_double(self.as_raw_mut_BackgroundSubtractorMOG(), background_ratio) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_noise_sigma(&mut self, noise_sigma: f64) -> Result<()> {
-		unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setNoiseSigma_double(self.as_raw_mut_BackgroundSubtractorMOG(), noise_sigma) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_BackgroundSubtractorMOG_setNoiseSigma_double(self.as_raw_mut_BackgroundSubtractorMOG(), noise_sigma) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -576,7 +633,8 @@ pub trait SyntheticSequenceGeneratorTrait: core::AlgorithmTrait + crate::bgsegm:
 	fn get_next_frame(&mut self, frame: &mut dyn core::ToOutputArray, gt_mask: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(frame);
 		output_array_arg!(gt_mask);
-		unsafe { sys::cv_bgsegm_SyntheticSequenceGenerator_getNextFrame_const__OutputArrayR_const__OutputArrayR(self.as_raw_mut_SyntheticSequenceGenerator(), frame.as_raw__OutputArray(), gt_mask.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_bgsegm_SyntheticSequenceGenerator_getNextFrame_const__OutputArrayR_const__OutputArrayR(self.as_raw_mut_SyntheticSequenceGenerator(), frame.as_raw__OutputArray(), gt_mask.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -630,7 +688,9 @@ impl SyntheticSequenceGenerator {
 	pub fn new(background: &dyn core::ToInputArray, object: &dyn core::ToInputArray, amplitude: f64, wavelength: f64, wavespeed: f64, objspeed: f64) -> Result<crate::bgsegm::SyntheticSequenceGenerator> {
 		input_array_arg!(background);
 		input_array_arg!(object);
-		unsafe { sys::cv_bgsegm_SyntheticSequenceGenerator_SyntheticSequenceGenerator_const__InputArrayR_const__InputArrayR_double_double_double_double(background.as_raw__InputArray(), object.as_raw__InputArray(), amplitude, wavelength, wavespeed, objspeed) }.into_result().map(|r| unsafe { crate::bgsegm::SyntheticSequenceGenerator::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_bgsegm_SyntheticSequenceGenerator_SyntheticSequenceGenerator_const__InputArrayR_const__InputArrayR_double_double_double_double(background.as_raw__InputArray(), object.as_raw__InputArray(), amplitude, wavelength, wavespeed, objspeed) }.into_result()?;
+		let ret = unsafe { crate::bgsegm::SyntheticSequenceGenerator::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
